@@ -13,7 +13,7 @@
 #' Brandon Whitcher \email{bwhitcher@@gmail.com}
 #' @references
 #' ANALYZE 7.5\cr
-#' \url{https://rportal.mayo.edu/bir/ANALYZE75.pdf}\cr
+#' \url{http://eeg.sourceforge.net/ANALYZE75.pdf}\cr
 #' NIfTI-1\cr
 #' \url{http://nifti.nimh.nih.gov/}
 #'
@@ -22,11 +22,11 @@ setGeneric("orient", function(object) standardGeneric("orient"))
 #' @rdname orient-methods
 #' @aliases orient,anlz-method
 #' @export
-setMethod("orient", "anlz", function(object) { object@"orient" })
+setMethod("orient", "anlz", function(object) object@"orient")
 #' @rdname orient-methods
 #' @aliases orient<- 
 #' @export
-setGeneric("orient<-", function(object, value) { standardGeneric("orient<-") })
+setGeneric("orient<-", function(object, value) standardGeneric("orient<-"))
 #' @rdname orient-methods
 #' @aliases orient<-,anlz-method
 #' @export
