@@ -13,7 +13,7 @@
 #' Brandon Whitcher \email{bwhitcher@@gmail.com}
 #' @references
 #' ANALYZE 7.5\cr
-#' \url{https://rportal.mayo.edu/bir/ANALYZE75.pdf}\cr
+#' \url{http://eeg.sourceforge.net/ANALYZE75.pdf}\cr
 #' NIfTI-1\cr
 #' \url{http://nifti.nimh.nih.gov/}
 #'
@@ -22,11 +22,11 @@ setGeneric("smin", function(object) standardGeneric("smin"))
 #' @rdname smin-methods
 #' @aliases smin,anlz-method
 #' @export
-setMethod("smin", "anlz", function(object) { object@"smin" })
+setMethod("smin", "anlz", function(object) object@"smin")
 #' @rdname smin-methods
 #' @aliases smin<- 
 #' @export
-setGeneric("smin<-", function(object, value) { standardGeneric("smin<-") })
+setGeneric("smin<-", function(object, value) standardGeneric("smin<-"))
 #' @rdname smin-methods
 #' @aliases smin<-,anlz-method
 #' @export
