@@ -1,6 +1,9 @@
 context("sizeof_hdr attribute")
 
-aim <- readANALYZE(system.file("anlz/avg152T1.hdr.gz", package = "oro.nifti"))
+suppressWarnings({
+  aim <- readANALYZE(system.file("anlz/avg152T1.hdr.gz", 
+                                 package = "oro.nifti"))
+})
 nim <- readNIfTI(system.file("nifti/mniRL.nii.gz", package = "oro.nifti"))
 
 test_that("sizeof_hdr()", {
@@ -14,3 +17,12 @@ test_that("sizeof.hdr()", {
 })
 
 
+test_that("sizeof_hdr()", {
+  expect_silent({
+    sizeof_hdr(aim) = 348
+    })
+  expect_silent({
+    sizeof_hdr(nim) = 348
+  })
+})
+
